@@ -21,49 +21,56 @@
 
 import re
 import subprocess
-from distutils.spawn import find_executable
 
 __author__ = "Duncan Macleod <duncan.macleod@ligo.org>"
 
-KLIST_EXE = find_executable("klist")
+KLIST_EXE = "klist"
 KLIST_PRINCIPAL_RE = re.compile(
     r"\nDefault principal: ([\w\.@]+)",
     re.M,
 )
 
 
-def _find_executable(name):
-    exe = find_executable(name)
-    if exe is None:
-        raise OSError("cannot find {0!r}".format(name))
-    return exe
-
-
-def has_credential(klist=KLIST_EXE):
+def has_credential(*args, klist=KLIST_EXE):
     """Run ``klist`` to determine whether a kerberos credential is available.
 
     Parameters
     ----------
+    *args : `str`, optional
+        extra arguments to pass to ``klist``, note that the ``-s`` option
+        is always passed to ``klist``
+
     klist : `str`, optional
-        path to the ``klist`` executable, defaults to searching ``$PATH``
+        path to the ``klist`` executable
 
     Returns
-    ----------
+    -------
     True
         if ``klist -s`` indicates a valid credential
     False
         otherwise (including klist failures)
+
+    Examples
+    --------
+    >>> has_credential()
+    False
+    >>> has_credential("mykrb5cc", klist="/opt/special/bin/klist")
+    True
+
+    See also
+    --------
+    klist(1)
+        for details of options accepted by ``klist``
     """
     # run klist to check credentials
-    klist = klist or _find_executable("klist")
     try:
-        subprocess.check_output([klist, "-s"])
+        subprocess.check_output([klist, "-s"] + list(args))
     except subprocess.CalledProcessError:
         return False
     return True
 
 
-def find_principal(klist=KLIST_EXE):
+def find_principal(*args, klist=KLIST_EXE):
     """Determine the default principal for an active kerberos credential
 
     Parameters
@@ -71,9 +78,36 @@ def find_principal(klist=KLIST_EXE):
     klist : `str`, optional
         path to the ``klist`` executable, defaults to searching ``$PATH``
     """
-    klist = klist or _find_executable("klist")
-    out = subprocess.check_output([klist]).decode("utf-8")
+    out = subprocess.check_output([klist] + list(args)).decode("utf-8")
     try:
         return KLIST_PRINCIPAL_RE.search(out).groups()[0]
     except (AttributeError, IndexError):  # failed to parse principal
         raise RuntimeError("failed to parse principal from `klist` output")
+
+
+def realm(principal):
+    """Return the kerbeos realm name from a principal
+
+    Parameters
+    ----------
+    principal : `str`
+        the kerberos principal to parse
+
+    Returns
+    -------
+    realm : `str`
+        the realm name
+
+    Examples
+    --------
+    >>> realm('marie.curie@EXAMPLE.ORG')
+    'EXAMPLE.ORG'
+    """
+    try:
+        user, realm = principal.rsplit("@", 1)
+    except ValueError as exc:  # no "@" character
+        exc.args = (
+            f"invalid kerberos principal '{principal}'",
+        )
+        raise
+    return realm
