@@ -28,6 +28,10 @@ from .kerberos import (
     find_principal as find_krb5_principal,
     realm as krb5_realm,
 )
+from .logging import (
+    init_logging,
+    reset_logging,
+)
 from .utils import get_idp_url
 
 __all__ = [
@@ -45,6 +49,8 @@ class Session(ECPSession):
             username=None,
             password=None,
             cookiejar=None,
+            debug=False,
+            **kwargs,
     ):
 
         if kerberos is None:
@@ -64,9 +70,19 @@ class Session(ECPSession):
             kerberos=kerberos,
             username=username,
             password=password,
+            **kwargs,
         )
 
         # load cookies from existing jar or file
         self.cookies = ECPCookieJar()
         if cookiejar:
             self.cookies.update(cookiejar)
+
+        # configure debugging
+        self.debug = debug
+        if self.debug:
+            init_logging(level="DEBUG")
+
+    def close(self):
+        reset_logging()
+        return super().close()
