@@ -25,6 +25,8 @@ from urllib import parse as urllib_parse
 
 from OpenSSL import crypto
 
+from requests import HTTPError
+
 from .env import DEFAULT_IDP
 from .cookies import extract_session_cookie
 from .requests import _ecp_session
@@ -67,6 +69,9 @@ def get_cookie(
     session : `requests.Session`, optional
         an active `requests.Session` to use with the query
 
+    return_all : `bool`, optional
+        return all cookies from the authentication request
+
     Returns
     -------
     cookie : `http.cookiejar.Cookie`
@@ -79,6 +84,11 @@ def get_cookie(
             url=url,
         )
 
+        # make the original request, it may introduce more cookies
+        if url != DEFAULT_SP_URL:
+            resp = sess.get(url=url)
+            resp.raise_for_status()
+
         # extract the shibsession cookie for the SP:
         #   we do this by searching for all cookies associated with
         #   the relevant SP domain, and picking the most recent one
@@ -137,9 +147,9 @@ def get_cert(
             'Cookie': 'CSRF={0}; {1.name}={1.value}'.format(csrfstr, cookie),
         }
         p12password = (
-            random_string(16, string.ascii_letters) +
-            random_string(2, string.digits) +
-            random_string(2, '!@#$%^&*()')
+            random_string(16, string.ascii_letters)
+            + random_string(2, string.digits)
+            + random_string(2, '!@#$%^&*()')
         )
         certdata = urllib_parse.urlencode({
             'submit': 'pkcs12',
@@ -152,6 +162,11 @@ def get_cert(
             data=certdata,
             headers=headers,
         )
+        try:
+            resp.raise_for_status()
+        except HTTPError as exc:
+            exc.args = (f"{exc}: '{resp.text}'",)
+            raise
 
         if debug:
             print("Certificate received.")
